#include "BuddyEdit.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <qlistbox.h>
#include <qlabel.h>
#include <qpushbutton.h>
#include <qmessagebox.h>
#include <vector.h>

BuddyEdit::BuddyEdit(const char * buddyFile, QWidget * parent, const char * name, WFlags fl) : BuddyEditBase (parent, name, fl) {
  FILE *file;
  char name[256];
   
  listBoxNames->clear();

  strcpy (fileName, buddyFile);
  file = fopen (fileName, "r");

  if (file == NULL) goto next;

  // Load into vector 
  while (fgets(name, 9999, file) != NULL) {
    buddyItem *next = (buddyItem *) malloc (sizeof(buddyItem));
    strcpy (next->name, name);
    fgets(next->btID, 9999, file);
    fgets(next->phoneNum, 9999, file);
    
    // Truncate new line for everything
    next->name[strlen(next->name)-1] = next->btID[strlen(next->btID)-1] = next->phoneNum[strlen(next->phoneNum)-1] = 0;
    list.push_back(next);
  }

next:;
  // Load into listBox
  for (vector<buddyItem *>::iterator it = list.begin(); it < list.end(); it++) {
    buddyItem *thisItem = *it;
    listBoxNames->insertItem(thisItem->name);
  }
  listBoxNames->setSelectionMode(QListBox::Single);

  // BuddyChanger
  buddyChange = new BuddyChange (this);
   
  // Signals and slots
  connect (listBoxNames, SIGNAL(highlighted(int)), this, SLOT(selectionChanged(int)));
  connect (pushButtonRemove, SIGNAL(clicked()), this, SLOT(removeItem()));
  connect (pushButtonExit, SIGNAL(clicked()), this, SLOT(finish()));
  connect (pushButtonCancel, SIGNAL(clicked()), this, SLOT(closeProg())); 
  connect (pushButtonNew, SIGNAL(clicked()), this, SLOT(add()));
  connect (pushButtonEdit, SIGNAL(clicked()), this, SLOT(change()));
  connect (buddyChange, SIGNAL(dataChanged(int, const char *, const char *, const char *)), this,
    SLOT(valueChanged(int, const char *, const char *, const char *)));
}

BuddyEdit::~BuddyEdit() { }

void BuddyEdit::closeProg() {
  // Don't delete it because it can be re-run again by calling module
  // delete buddyChange;
  hide();
}

void BuddyEdit::finish() {
  FILE *file = fopen (fileName, "w");

  // Write items into file, clear memory
  for (vector<buddyItem *>::iterator it = list.begin(); it < list.end(); it++) {
    buddyItem *thisItem = *it;
    fprintf (file, "%s\n%s\n%s\n", thisItem->name, thisItem->btID, thisItem->phoneNum);

    free(thisItem);
  }
  fclose(file);

  // The buddy list has changed!
  emit buddyListChanged();
  closeProg();
}

void BuddyEdit::selectionChanged(int newIndex) {
  char newLabel[1000];

  if (newIndex == -1) {
    labelProperties->setText("");
    return;
  }
  
  strcpy (newLabel, list[newIndex]->name);
  strcat (newLabel, "\nBlueTooth ID: ");
  strcat (newLabel, list[newIndex]->btID);
  strcat (newLabel, "\nPhone: ");
  strcat (newLabel, list[newIndex]->phoneNum);
  labelProperties->setText(newLabel);
}

void BuddyEdit::removeItem() {
  int current = listBoxNames->currentItem();

  if (current < 0) return;

  // Confirm removal
  char remove[300];
  strcpy (remove, "Remove ");
  strcat (remove, list[current]->name);
  strcat (remove, " from buddylist?");
  switch (QMessageBox::information (this, "Confirm Removal", remove, QMessageBox::Yes, QMessageBox::No)) {
    case QMessageBox::No:
      return;
  }
  // Remove
  free (list[current]);
  list.erase(list.begin() + current, list.begin() + current + 1);
  listBoxNames->removeItem(current);
}

void BuddyEdit::add() {
  changeItem(list.size());
}

void BuddyEdit::change() {
  if (listBoxNames->currentItem() < 0) return;
  changeItem(listBoxNames->currentItem());
}

void BuddyEdit::changeItem(int index) {
  if (index == list.size()) {
    buddyChange->execute(index, "", "", "");
  } else {
    buddyChange->execute(index, list[index]->name, list[index]->btID, list[index]->phoneNum);
  }
}

void BuddyEdit::valueChanged (int index, const char * name, const char * btID, const char * phoneNum) {
  char newLabel[1000];
  if (index == list.size()) {
    // Add new item
    buddyItem * next = (buddyItem *) malloc (sizeof(buddyItem));

    strcpy (next->name, name);
    strcpy (next->btID, btID);
    strcpy (next->phoneNum, phoneNum);

    list.push_back(next);
    listBoxNames->insertItem(next->name);
  } else {
    // Change existing item
   
    strcpy (list[index]->name, name);
    strcpy (list[index]->btID, btID);
    strcpy (list[index]->phoneNum, phoneNum);

    // Change listBoxNames
    listBoxNames->changeItem(list[index]->name, index);

    // Change what is shown
    strcpy (newLabel, list[index]->name);
    strcat (newLabel, "\nBlueTooth ID: ");
    strcat (newLabel, list[index]->btID);
    strcat (newLabel, "\nPhone: ");
    strcat (newLabel, list[index]->phoneNum);
    labelProperties->setText(newLabel);
  }
}  
