Buffers Files Tools Edit Search Mule C++ Help
/*****************************************************************************
 * File: MoodTrainer.h
 * Author: Chris Moh and Anmol Madan, MIT Human Dynamics Group
 * http://groupmedia.media.mit.edu/
 * Copyright (C) 2006 MIT Media Lab
 *
 * Adapted from OpineViewerEngine.cpp
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *****************************************************************************/



#ifndef MOOD_TRAINER_H
#define MOOD_TRAINER_H

#ifndef __cplusplus
#error "This is a C++ header file; it requires C++ to compile."
#endif

#include <qwidget.h>
#include <qlabel.h>
#include <qlistbox.h>
#include <qpixmap.h>
#include <qlineedit.h>
#include <qpushbutton.h>
#include <time.h>

#include "ZMainWidget.h"
#include "ZScrollView.h"
#include "ZPushButton.h"
#include "ZMultiLineEdit.h"
#include "ZSMS.h"

#include "GetMood.h"

typedef struct {
    char name[1024], btID[1024], phoneNum[1024];
} buddyItem;

typedef struct {
    int duration;
    char btID[1024];
} onlineChecker;

class MoodTrainer : public ZMainWidget
{
    Q_OBJECT

public:

  MoodTrainer(int pollTime = 30, int envScanPollTime = 300, const char * buddyFile = "buddy.txt", QWidget * parent = 0, const char * name = 0, WFlags fl = 0);
  ~MoodTrainer();

private:

  QLabel * locLabel;
  QLabel * moodLabel;
  QLabel * buddyLabel;
  QLabel * logoLabel;
  QLabel * bannerLabel;

  QPixmap * logo;
  QPixmap * banner;

  QWidget * pCST;
  ZPushButton * pLeftBtn;
  ZPushButton * pMidBtn;
  ZPushButton * pRightBtn;
  QPopupMenu * pCSM;
  ZScrollView * pContent;
  QListBox * listBoxMyBuddies;

  QLineEdit * content;
  QPushButton * writeNote;

  char buddyFile[256];
  char tempFile[256];
  char notesFile[256];
//  char asFile[256];
//  int asFileNum;  // The AS File number we are at
  int diskFullThreshold; // The percentage before we consider the disk to be full
  int pollTime;  // How long before we check envtmp.txt etc.  
  int envScanPollTime;   // How long before EnvScan should poll again
  int alarmTime;   // How long that envmap.txt doesn't change in size before we start sounding the alarm
  int envMapSize, howLong;     // Size of envmap.txt, and how long it has stayed at that size
  int cacheTime;  // How many seconds we should cache the seenID list
  int buddySize, onlineSize, seenSize;
  int asRunning;  // Is AS running?
  int timeBetweenAsk;   // How long (in s) should the time between asking moods be?
  time_t lastMoodAskedTime;  // Time when the last mood was asked
  int runState, idAddBuddy, idRemoveBuddy, idOptions;
  int displayLock;
  
  buddyItem * buddyList[1000], * onlineList[1000];
  onlineChecker * seenID[1000];
  // BuddyEdit * buddyEdit;

  QTimer * timer;  
  GetMood * getMood;

  int getFileSize (const char * fileName);
  int diskFull(const char * fileSystem);
  void onlineListRefresh();
  void closeProg();
  void startAS();
  void stopAS();
  void playBuzz(char * pcmfile);
  
  // For future releases 
  // ZSMS * pSMS;

private slots:

  void buddyListRefresh();
//  void startBuddyEdit();
  void done();
  void startOrStop();
  void timerTick();
  void moodChosen(int mood);
  void slotSelectMenu(int idMenu);
  void writeNotes();

};

#endif
// MOOD_PHONES_H
