#ifndef MOODTRAINER_H
#define MOODTRAINER_H

#include "MoodTrainerBase.h"
#include "BuddyEdit.h"
#include "GetMood.h"
#include <vector.h>
#include <qtimer.h>

#define X86
#define DEBUG

// We will store these objects in a queue of all "seen" btIDs 
// the duration field is the time this has been "alive"
typedef struct {
  char btID[256];
  int duration;
} onlineChecker;

class MoodTrainer : public MoodTrainerBase {
  Q_OBJECT

public:
  MoodTrainer(int pollTime = 15, const char * buddyFile = "buddy.txt", QWidget * parent = 0, const char * name = 0, WFlags fl = 0);
  ~MoodTrainer();

private:
  char buddyFile[256];
  char tempFile[256];
  char awFile[256];
  int awFileNum;  // The AW File number we are at
  int diskFullThreshold; // The percentage before we consider the disk to be full
  int pollTime;  // How long before we check envtmp.txt etc.  We will ask EnvScan to poll every (pollTime - 1) seconds
  int alarmTime;   // How long that envmap.txt doesn't change in size before we start sounding the alarm
  int envMapSize, howLong;     // Size of envmap.txt, and how long it has stayed at that size
  int cacheTime;  // How many seconds we should cache the seenID list
  vector<buddyItem *> buddyList, onlineList;
  vector<onlineChecker *> seenID;
  BuddyEdit * buddyEdit;
  GetMood * getMood;
  QTimer * timer;

  int getFileSize (const char * fileName);
  int diskFull(const char * fileSystem);
  void onlineListRefresh();
  void startAW(int awFileNum);
  void killAW();
  void closeProg();

private slots:
  void buddyListRefresh();
  void startBuddyEdit();
  void done();
  void startRunning();
  void timerTick();
  void moodChosen(int mood);
};

#endif
// MOODTRAINER_H
