/*
 * File: MyWidget.cpp
 * Description: This file implementation the MyWidget class,
 *              it illustrate the usage of :
 *                 ZSMS, ZScrollView, ZPushButton, ZMultiLineEdit, QLabel, QPopupMenu
 *
 *                            Motorola General Business Information
 *                     Copyright (c) 2004 Motorola Ltd. All Rights Reserved
 *
 * This file is part of a sample program for Motorola EzX SDK.  This sample
 * program may be used, distributed and modified without limitation.
 */

#include <qapplication.h>
#include <qpushbutton.h>
#include <qtextstream.h>

#include <ZSMS.h>
#include <ZMessageBox.h>

#include "MyWidget.h"

/*
 * Constructs a MyWidget widget.
 */
MyWidget::MyWidget( QWidget *parent, const char *name )
    : ZMainWidget( TRUE, parent, name )
{
    pSMS = new ZSMS( this );
    if( ZSMS_ERROR_CODE__SUCCESS != pSMS->enableInterceptCheck( TRUE ) )
        ZMessageBox::information( 0, 0, "Fail to init intercepting SMS.", "OK", NULL, NULL );

    bJustSend = TRUE;

    pContent = (ZScrollView*)this->getContentWidget();
    pContent->enableClipper(TRUE);

    pCST = this->getCSTWidget();
    pLeftBtn = new ZPushButton( "CST_Menu", pCST, ZPushButton::JoinRight | ZPushButton::CSTStyle );
    pMidBtn = new ZPushButton( pCST, ZPushButton::JoinLeft | ZPushButton::JoinRight | ZPushButton::CSTStyle );
    pRightBtn = new ZPushButton( "CST_Exit", pCST, ZPushButton::JoinLeft | ZPushButton::CSTStyle );

    pCSM = new QPopupMenu( this );
    idSend = pCSM->insertItem( "Just send" );
    idSendWithResult = pCSM->insertItem( "Send with result" );
    pCSM->setItemChecked( idSend,  bJustSend );
    pCSM->setItemChecked( idSendWithResult,  !bJustSend );

    pLeftBtn->setGeometry( ZDiffR(CstR, Cst3_1R) );
    pLeftBtn->setPopup( pCSM );
    pMidBtn->setGeometry( ZDiffR(CstR, Cst3_2R) );
    pMidBtn->setText( "Send the SMS" );
    connect( pMidBtn, SIGNAL( clicked() ), this, SLOT( slotSendSMS() ) );
    pRightBtn->setGeometry( ZDiffR(CstR, Cst3_3R) );
    connect( pRightBtn, SIGNAL( clicked() ), qApp, SLOT( quit()) );
    connect( pCSM, SIGNAL( activated(int) ), this, SLOT( slotSelectMenu(int) ) );

    pLabel = new QLabel( pContent->viewport() );
    pLabel->setText( "To : " );
    pLabel->resize( 40, 24 );
    pAddr = new ZMultiLineEdit( pContent->viewport(), TRUE, 1 );
    pAddr->setFixedWidth( 210 );
    pAddr->setIndent( 40 );
    QValueList<QUuid> flist1;
    flist1.append( IMID_NUMBER_KB );
    setInputMethods( pAddr, IMID_NUMBER_KB, flist1 );
    pContent->addChild( pLabel, 10, 30 );
    pContent->addChild( pAddr, 10, 30 );

    pBody = new ZMultiLineEdit( pContent->viewport(), TRUE, 5 );
    pBody->resize( 210, pBody->height() );
    pContent->addChild( pBody, 12, 72, TRUE );


    connect( pSMS, SIGNAL( indOfIncomingMsg(const ZSMS_IncomingMsg &, const ZSMS_MsgRecordID &) ),
             this, SLOT( slotIncomingMsg(const ZSMS_IncomingMsg &, const ZSMS_MsgRecordID &) ) );

    connect( pSMS, SIGNAL( rspnsOfSendMsgWithResult(ZSMS_SEQU_ID_T, ZSMS_ERROR_CODE_T) ),
             this, SLOT( slotHandleSendError(ZSMS_SEQU_ID_T, ZSMS_ERROR_CODE_T) ) );
}


void MyWidget::slotSendSMS()
{
    ZSMS_OutgoingMsg * pOutMsg = new ZSMS_OutgoingMsg( pAddr->text(), pBody->text() );

    ZSMS_SEQU_ID_T tempID = 0;
    pSMS->sendMsgWithResult( &tempID, *pOutMsg );
    QString tempStr;
    QTextOStream( &tempStr ) << "The msg's id is : " << tempID;
    ZMessageBox::information( 0, 0, tempStr, "OK", NULL, NULL );
}


void MyWidget::slotIncomingMsg( const ZSMS_IncomingMsg & InMsg, const ZSMS_MsgRecordID & InMsgID )
{
    int ret = ZMessageBox::information( this, 0, "You got an SMS. Check it?", "OK", "Cancel", NULL );
    if( 0 == ret )
    {
        pSMS->notifyInterceptCheckResult( InMsgID, TRUE );
        QString tempStr = "From :\n" + InMsg.getAddress();
        ZMessageBox::information( 0, 0, tempStr, "OK", NULL, NULL );
        tempStr = InMsg.getMsgBody();
        ZMessageBox::information( 0, 0, tempStr, "OK", NULL, NULL );
        tempStr = "Time :\n" + (InMsg.getSentTime()).toString();
        ZMessageBox::information( 0, 0, tempStr, "OK", NULL, NULL );
    }
    else
    {
        pSMS->notifyInterceptCheckResult( InMsgID, FALSE );
    }
}


void MyWidget::slotHandleSendError( ZSMS_SEQU_ID_T sequID, ZSMS_ERROR_CODE_T errCode )
{
    QString tempStr;
    QTextOStream( &tempStr ) << "The msg's id is : " << sequID << ";\nIt's error code is : " << errCode;
    ZMessageBox::information( 0, 0, tempStr, "OK", NULL, NULL );
}


void MyWidget::slotSelectMenu( int idMenu)
{
    if( idMenu == idSend )
    {
        if( bJustSend == FALSE)
        {
            bJustSend = TRUE;
            pCSM->setItemChecked( idSend,  bJustSend );
            pCSM->setItemChecked( idSendWithResult,  !bJustSend );
            pMidBtn->setText( "Send the SMS" );
        }
    }
    else if( idMenu == idSendWithResult )
    {
        if( bJustSend == TRUE)
        {
            bJustSend = FALSE;
            pCSM->setItemChecked( idSend,  bJustSend );
            pCSM->setItemChecked( idSendWithResult,  !bJustSend );
            pMidBtn->setText( "Send with result" );
        }
    }
}

